.s3direct {
  float: left;
}

.s3direct .progress {
  background: #333;
  width: 200px;
}

.s3direct .file-remove {
  margin-top: 10px;
  text-transform: uppercase;
}

.s3direct .progress,
.s3direct .file-link,
.s3direct .file-remove,
.s3direct .file-input {
  display: none;
  float: left;
  clear: left;
}

.s3direct.progress-active .progress,
.s3direct.link-active .file-link,
.s3direct.link-active .file-remove,
.s3direct.form-active .file-input {
  display: block;
}